%%
%% open file  with data
%% calculates derived parameters
%% save into new file 
%% changed december 12: Lnuv,Lfuv use: Lambda_nuv = 2271 , Lambda_fuv = 1528;  . Ho =70
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

'started'
openfile = 'GST1z0_03_dec12_OII.csv'; %file with data to open
savefile = 'mGST1z0_03_dec12_OII.csv'; % new file to save to. if allready exist it will be replaced

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

readdata = 'y'; % put ='y' inorder to load data from file into matlab workspace
if readdata == 'y'
%%% read header %%%
fid = fopen(openfile);
Header = fgetl(fid);
fclose(fid);
%%% read data %%%
Data = csvread(openfile,1,0);
Dsize = size(Data);
%%%%%%%%%%%%%%%%%
fprintf(1,['done reading ' num2str(Dsize(1)) ' , ' num2str(Dsize(2))]);
%%% define parameters %%% dont forget to select the right columns
redshift = Data(:,16);

expRu = Data(:,39); % exponential scale radius, arcsec
expRr = Data(:,43);
expRz = Data(:,47);

petR50u = Data(:,49); % Petrosian half light radius, arcsec

u = Data(:,29); % apparanet magnitud (corrected for 'milkyway extinction', no k-corrections)
g = Data(:,31);
r = Data(:,33);
i = Data(:,35);
z = Data(:,37);

FHa = Data(:,19); % line flux from SDSS
FHb = Data(:,23);
FN2 = Data(:,27);
FO3 = Data(:,28);

WHa = Data(:,20); % calculated equivalent width from SDSS, angstrom
ewHa = Data(:,21); % tabulated equivalent width from SDSS
sigmaHa = Data(:,22); % line width of Ha, angstrom

Fnuv = Data(:,1); % flux near ultra viloet, from Galex, Jansky 
Ffuv = Data(:,5); % flux far ultra viloet, from Galex

nuv_mag = Data(:,3);
fuv_mag = Data(:,7);

%%%%%%%%%%%%%%%%%%%%
end

%%% calculate stuff %%% check that things are correct

 c = 3*10^8; %m/s
 H = 70 * 10 ^3; %m/s/Mpc;

D = c.*redshift./H; %simplifyed distance, Mpc


AbsMagu = getM(D, u); %absolute magnitudes
AbsMagg = getM(D, g); 
AbsMagr = getM(D, r); 
AbsMagi = getM(D, i); 
AbsMagz = getM(D, z); 
AbsMagnuv = getM(D,nuv_mag);
AbsMagfuv = getM(D,fuv_mag);

Ru = getradius(D, expRu);  % [kpc]
Rr = getradius(D, expRr);  % [kpc]
Rz = getradius(D, expRz);  % [kpc]

Oa = 9.12 + 0.73.*log10(FN2 ./ FHa ) ; %oxygen abundance

% Luminosities,  
%DeltaLambda_nuv = 732; %   bandwidth for nuv 
%DeltaLambda_fuv = 268;  % 
Lambda_nuv = 2271;% 
Lambda_fuv = 1528;%  
Lsolar = 3.827 * 10^33; %ergs/s. solar bolometric luminosity

Dcm = D.*10^8.*3.09.*10.^16; %Mpc -> cm,
Fnuv_cgs = Fnuv.* 1.28.*10^-17 .* Lambda_nuv; %Jy -> erg/cm^2/s/ (cgs ??)
Ffuv_cgs = Ffuv.* 1.28.*10^-17 .* Lambda_fuv;

Lnuv = 4.*pi.*(Dcm).^2.*(Fnuv_cgs) ./Lsolar;% solar bolometric luminosity unit
Lfuv = 4.*pi.*(Dcm).^2.*(Ffuv_cgs) ./Lsolar;%

Ifuv = Lfuv./(2*pi*petR50u.^2); % "effective surface brightness" far UV luminosity and u radius

'done calculating stuff'
%%%%%%%%%%%%%%%%%%%%%%%


Col = [Fnuv_cgs Ffuv_cgs AbsMagnuv AbsMagfuv AbsMagu AbsMagg AbsMagr AbsMagi  Ru Rr Rz  Oa Lnuv Lfuv Ifuv];
Colhead = ',Fnuv_cgs,Ffuv_cgs,AbsMagnuv,AbsMagfuv,AbsMagu,AbsMagg,AbsMagr,AbsMagi,Ru,Rr,Rz,Oa,Lnuv,Lfuv,Ifuv';
addcol(openfile, savefile, Col, Colhead);

%% vissa problem fr att AbsMagz blev imaginr -> sparades ej. sdssdec
%% sparas konstigt 
%%%%%%%%%%%%%%%%%%%%%%%%%

'done'
